@@ -63,7 +63,7 @@ cal_widget_resize_for_cal_size(CalHomePlugin* desktop_plugin)
   if(cal_row_count == -1)
     cal_row_count = row_count;
   gtk_widget_set_size_request(desktop_plugin->event_list_container, 
-			      CAL_WIDGET_WIDTH, 
+			      CAL_WIDGET_WIDTH-8,
 			      CAL_WIDGET_ENTRY_ROW_HEIGHT*row_count);
   gtk_window_resize(GTK_WINDOW (desktop_plugin), 
 		    CAL_WIDGET_WIDTH, 
@@ -400,7 +400,10 @@ build_ui(CalHomePlugin *desktop_plugin)
 
   gtk_event_box_set_visible_window(GTK_EVENT_BOX(contents), FALSE);
   gtk_container_set_border_width(GTK_CONTAINER(contents), 0);
-  desktop_plugin->event_list_container  = gtk_vbox_new(TRUE, 0);
+
+  gint row_count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(desktop_plugin->event_list), NULL);
+  desktop_plugin->event_list_container  = gtk_table_new(1, 4, row_count);
+
   GtkWidget* title = gtk_hbox_new(FALSE, 0);
   GdkPixbuf* icon = load_calendar_applet_icon();
   desktop_plugin->day_image = gtk_image_new_from_pixbuf(icon);
@@ -462,10 +465,10 @@ build_ui(CalHomePlugin *desktop_plugin)
 		   G_CALLBACK(cal_home_button_release_show_month_view), 
 		   desktop_plugin);
 
-
-
   gtk_box_pack_start(GTK_BOX(box), title, FALSE, FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(box), desktop_plugin->event_list_container, FALSE, FALSE, 0);
+  GtkWidget* box2 = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_end(GTK_BOX(box2), desktop_plugin->event_list_container, FALSE, FALSE, 0); 
+  gtk_box_pack_start(GTK_BOX(box), box2, FALSE, FALSE, 0);
   gtk_container_add(GTK_CONTAINER(contents), box);
   gtk_widget_show_all(contents);
   return GTK_WIDGET(contents);
